package HTML::StyleStream::Plain;

# $Id: Plain.pm,v 1.11 1998/11/26 19:07:42 emanuel Exp $

use strict; 
use vars qw($VERSION $AUTOLOAD);
use Carp;
use IO::Handle;
 
$VERSION = join '', q$Revision: 1.11 $ =~ /([\d\.]+)/;

sub new {
  my($proto, %args) = @_;
  my $class = ref($proto) || $proto;
  my $self = bless {}, $class;
 
  if ($args{output}) { $self->{output} = $args{output} }
  else { $self->{output} = *STDOUT }

  $self->{save_stack} = [];
 
  return $self;
}
 
sub print {
  my $self = shift;
  if (@{$self->{save_stack}}) {
    ${$self->{save_stack}->[$#{$self->{save_stack}}]} .= join('', @_);
  } else {
    $self->{output}->print(@_);
  }
  return $self;
}
 
sub text {
  my $self = shift;
  $self->print(map { HTML::Entities::encode($_) } @_);
}
 
sub entity {
  my($self, $entity) = @_;
  $self->print("&$entity;");
}
 
sub nl {
  shift->print("\n");
}
 
sub print_tag {
  my $self = shift;
  my $tag = shift;
 
  $tag =~ s|^_|/|;
  $tag =~ s|_|-|g;

  my %attr = @_;
  my $s = '';
  while (@_) {
    my $name = shift; shift;
    if (exists $attr{$name}) {
      if (defined $attr{$name}) {
	$s .= " $name=\"" . HTML::Entities::encode($attr{$name}) . "\"";
      } else {
	$s .= " $name";
      }
      delete $attr{$name};
    }
  }
  $self->print("<$tag$s>");
}

sub start_save {
  my $self = shift;
  my $scalar = "";
  push @{$self->{save_stack}}, \$scalar;
}

sub end_save {
  my $self = shift;
  $self->{last_saved_text} = pop @{$self->{save_stack}}
    or die "HTML::StyleStream::Plain -- mismatched end_save";
}

sub last_saved_text {
  return ${shift->{last_saved_text}}
}
 
sub AUTOLOAD {
  my $self = shift;
  my $name = $AUTOLOAD;
  $name =~ s/.*://;
  $name =~ /[a-z]/ and confess "$name method not found";
  $self->print_tag($name, @_);
}

sub DESTROY {}

1;
